import "virtual:uno.css"

import "./assets/utils.css"
import "./assets/safe-area.css"

import "nprogress/nprogress.css"

import { createApp } from "vue"
import { createPinia } from "pinia"

import "vuetify/styles"
import { createVuetify } from "vuetify"
import { md3 } from "vuetify/blueprints"
import * as components from "vuetify/components"
import * as labsComponents from "vuetify/labs/components"
import * as directives from "vuetify/directives"

import "@mdi/font/css/materialdesignicons.min.css"
import "@fontsource/roboto/latin.css"
import "@unocss/reset/tailwind.css"

import nprogress from "nprogress";

import index from "./index.vue"
import router from "./router"

nprogress.configure({showSpinner: false})
nprogress.start()

window.onload = () => nprogress.done()

const app = createApp(index)

app.use(
  createVuetify({
    directives,
    components: {
      ...components,
      ...labsComponents
    },
    blueprint: md3,
    theme: {
      defaultTheme: "original",
      themes: {
        original: {
          colors: {
            primary: "#4a5099",
            secondary: "#2196f3",
            accent: "#009688",
            error: "#f44336",
            warning: "#ff9800",
            info: "#03a9f4",
            success: "#4caf50"
          }
        }
      }
    }
  })
)

app.use(createPinia())
app.use(router)

app.mount("#app")
